summaryrefslogtreecommitdiffstats
path: root/kdesktop/kdiconview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:11:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:11:21 -0600
commitf537c21b68e08f649b1b297bce8f3904603137e0 (patch)
treefb33065387509dea898c90022ddec9c3f8ede86d /kdesktop/kdiconview.h
parentdc5f267664506a312203c26bfe9001a448b0bb0f (diff)
downloadtdebase-f537c21b68e08f649b1b297bce8f3904603137e0.tar.gz
tdebase-f537c21b68e08f649b1b297bce8f3904603137e0.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kdesktop/kdiconview.h')
-rw-r--r--kdesktop/kdiconview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdesktop/kdiconview.h b/kdesktop/kdiconview.h
index c9feecaf7..7d8ff1527 100644
--- a/kdesktop/kdiconview.h
+++ b/kdesktop/kdiconview.h
@@ -33,7 +33,7 @@
class KDirLister;
class KonqSettings;
class KSimpleConfig;
-class KAccel;
+class TDEAccel;
class KShadowEngine;
class KDesktopShadowSettings;
@@ -60,7 +60,7 @@ public:
*/
void start();
- KActionCollection *actionCollection() { return &m_actionCollection; }
+ TDEActionCollection *actionCollection() { return &m_actionCollection; }
enum SortCriterion {
NameCaseSensitive = 0, NameCaseInsensitive, Size, Type, Date };
@@ -138,7 +138,7 @@ protected slots:
// slots connected to the popupmenu (actions)
void slotCut();
void slotCopy();
- void slotTrashActivated( KAction::ActivationReason reason, TQt::ButtonState state );
+ void slotTrashActivated( TDEAction::ActivationReason reason, TQt::ButtonState state );
void slotDelete();
void slotPopupPasteTo();
void slotProperties();
@@ -200,10 +200,10 @@ private:
static void readIconPosition(KSimpleConfig *config, int &x, int &y);
/** Our action collection, parent of all our actions */
- KActionCollection m_actionCollection;
+ TDEActionCollection m_actionCollection;
- /** KAccel object, to make the actions shortcuts work */
- KAccel *m_accel;
+ /** TDEAccel object, to make the actions shortcuts work */
+ TDEAccel *m_accel;
bool m_bNeedRepaint;
bool m_bNeedSave;